Stan Math Library: std Namespace Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Namespace List
- Namespace Members

Classes | Functions
std Namespace Reference

## Classes
struct | numeric_limits< stan::math::fvar< T > >
struct | numeric_limits< stan::math::var >
| Specialization of numeric limits for var objects. More...

## Functions
int | isinf (const stan::math::var &a)
| Checks if the given number is infinite. More...
int | isnan (const stan::math::var &a)
| Checks if the given number is NaN. More...

## Function Documentation

int std::isinf | ( | const stan::math::var & | a | ) |
| inline

Checks if the given number is infinite.

Return `true` if the value of the a is positive or negative infinity.

Parameters

  a | Variable to test.

Returns
  `true` if value is infinite.

Definition at line 18 of file std_isinf.hpp.

int std::isnan | ( | const stan::math::var & | a | ) |
| inline

Checks if the given number is NaN.

Return `true` if the value of the specified variable is not a number.

Parameters

  a | Variable to test.

Returns
  `true` if value is not a number.

Definition at line 18 of file std_isnan.hpp.

[ Stan Home Page ] © 2011–2016, Stan Development Team.